import 'package:flutter/material.dart';
import 'package:text_demo/demo_formatter.dart';
import 'package:text_demo/demo_readable.dart';

import 'demo_validator.dart';

void main() {
  runApp(const XinlakeTextDemo());
}

class XinlakeTextDemo extends StatelessWidget {
  const XinlakeTextDemo({Key? key}) : super(key: key);

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Xinlake-Text Demo',
      theme: ThemeData(
        primaryColor: Colors.teal,
        brightness: Brightness.dark,
        errorColor: Colors.deepOrange,
      ),
      home: const DemoPage(),
    );
  }
}

class DemoPage extends StatefulWidget {
  const DemoPage({Key? key}) : super(key: key);

  @override
  State<DemoPage> createState() => _DemoState();
}

class _DemoState extends State<DemoPage> {
  static const _demos = [
    "Validator",
    "Readable",
    "Formatter",
  ];

  String _demoTitle = _demos[0];

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(_demoTitle),
      ),
      body: Builder(
        builder: (context) {
          switch (_demoTitle) {
            case "Validator":
              return const ValidatorDemo();
            case "Readable":
              return const ReadableDemo();
            case "Formatter":
              return const FormatterDemo();
            default:
              return const Center(child: Text("Xinlake-Text Demo"));
          }
        },
      ),
      drawer: Drawer(
        child: ListView(
          padding: EdgeInsets.zero,
          children: [
            Container(
              padding: const EdgeInsets.all(10),
              alignment: Alignment.center,
              child: Text(
                'Xinlake-Text',
                style: Theme.of(context).textTheme.headline6,
              ),
            ),
            ..._demos.map((item) {
              return TextButton(
                child: Padding(
                  padding: const EdgeInsets.all(10),
                  child: Text(item, textScaleFactor: 1.2),
                ),
                onPressed: () {
                  setState(() => _demoTitle = item);
                  Navigator.of(context).pop();
                },
              );
            }).toList()
          ],
        ),
      ),
    );
  }
}
